%define libsystemd_major 0
%define libudev_major 1

%define libname %mklibname %{name} %{libsystemd_major}

%define libdaemon %mklibname systemd-daemon 0
%define libjournal %mklibname systemd-journal 0
%define liblogin %mklibname systemd-login 0
%define libid128 %mklibname systemd-id 128 0

%define libudev %mklibname udev %{libudev_major}
%define libudev_devel %mklibname -d udev

# (tmb) Turn off the brp-python-bytecompile automagic
%global _python_bytecompile_extra 0

# (ngompa): This implicitly requires pam_selinux
%bcond_with selinux

# (tmb): experiment with homed
%bcond_without homed

# Iurt causes issues with the test execution,
# so for now, it's disabled by default...
%bcond_with check

# stable branches now have patch levels
%define systemd_branch 253
%define systemd_patch  16

# (tv) So that main package doesn't pull pkgconfig in basesystem:
%global __requires_exclude pkgconfig

Summary:	A System and Session Manager
Name:		systemd
%if 0%{systemd_patch}
Version:	%{systemd_branch}.%{systemd_patch}
%else
Version:	%{systemd_branch}
%endif
Release:	%mkrel 1
License:	GPLv2+
Group:		System/Boot and Init
Url:		https://www.freedesktop.org/wiki/Software/systemd
%if 0%{systemd_patch}
Source0:	https://github.com/systemd/systemd-stable/archive/v%{version}/%{name}-%{version}.tar.gz
%else
Source0:	https://github.com/systemd/systemd/archive/v%{version}/%{name}-%{version}.tar.gz
%endif

Source10: 50-udev-mageia.rules
Source11: 69-printeracl.rules
# (hk) udev rules for zte 3g modems with drakx-net
Source12: 61-mobile-zte-drakx-net.rules

# (blino) net rules and helpers
Source20: 81-net.rules
Source21: udev_net_create_ifcfg
Source22: udev_net_action
Source23: udev_net.sysconfig

# Patching scheme:
## 100s: Upstream stable https://github.com/systemd/systemd-stable
## 400s: Upstream master https://github.com/systemd/systemd
## 450s: Changes proposed to upstream
## 500s: Mageia-specific changes

# upstream stable

# upstream master

# (ngompa): I'm not entirely sure why this is considered distro-specific...
Patch501: 0501-main-Add-failsafe-to-the-sysvinit-compat-cmdline-key.patch
Patch502: 0502-Disable-modprobe-pci-devices-on-coldplug-for-storage.patch
# (ngompa): Needs to be reworked
Source503: 0503-udev-Allow-the-udevadm-settle-timeout-to-be-set-via-.patch
Patch504: 0504-Mageia-Relax-perms-on-sys-kernel-debug-for-lspcidrak.patch
Patch505: 0505-udev-rules-Apply-SuSE-patch-to-restore-cdrom-cdrw-dv.patch
# (tmb) need check if still needed
Source506: 0506-pam_systemd-Always-reset-XDG_RUNTIME_DIR.patch
Source507: 0507-pam-Suppress-errors-in-the-SuSE-patch-to-unset-XDG_R.patch
Patch508: 0508-Add-path-to-locale-search.patch
# (tmb) silence udev version print as it breaks splash
Patch509: 0509-Silence-udev-version-print-during-boot-as-it-breaks-.patch
# (wally) fix build with new meson
Source510: 0510-Fix-build-with-new-meson.patch
# (tmb) treat nokmsboot like nomodeset
Patch511: 0511-login-mark-nokmsboot-fb-devices-as-master-of-seat.patch
# systemctl call to be "sourced" in X11 xinit
Patch512: 0512-systemd-250.2-xinit-to-be-sourced.patch
# (tmb) silence warning about missing native systemd
Patch513: 0513-systemd-revert-warning-about-sysv-file.patch

# mga#32201 (kekepower)
Patch514: systemd-253.10-mga-add-pam_limits-to-systemd-user.patch

BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	pkgconfig(dbus-1) >= 1.4.0
BuildRequires:	pkgconfig(libcap)
BuildRequires:	tcp_wrappers-devel
BuildRequires:	pam-devel
BuildRequires:	glib2-devel
BuildRequires:	pkgconfig(libnotify)
BuildRequires:	intltool
BuildRequires:	gettext-devel
BuildRequires:	gperf
BuildRequires:	pkgconfig(gee-1.0)
BuildRequires:	pkgconfig(libcryptsetup)
BuildRequires:	pkgconfig(libkmod)
BuildRequires:	pkgconfig(blkid)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	pkgconfig(libmicrohttpd)
BuildRequires:	pkgconfig(liblzma)
BuildRequires:	pkgconfig(libidn2)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	python3-jinja2
BuildRequires:	python3-lxml
BuildRequires:	pkgconfig(libqrencode)
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(xkbcommon)
BuildRequires:	pkgconfig(libseccomp)
%if %{with selinux}
BuildRequires:	pkgconfig(libselinux)
%endif
# for systemd-repart
BuildRequires:	pkgconfig(fdisk)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	libelfutils-devel
BuildRequires:	pkgconfig(libiptc)
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(polkit-gobject-1)
BuildRequires:	quota-devel
BuildRequires:	acl
BuildRequires:	tree
# synchronized with ExclusiveArch list from valgrind.spec
%ifarch %{ix86} x86_64 armv7hl aarch64
BuildRequires:	pkgconfig(valgrind)
%endif
%ifarch %{ix86} x86_64 aarch64
BuildRequires:	gnu-efi-devel
#BuildRequires:	qemu
%endif
BuildRequires:	git
BuildRequires:	gcc >= 12.0.1-0.20230121.1
BuildRequires:	binutils >= 1:2.40-1
# temp force new glibc
BuildRequires:  glibc >=  6:2.33-2
BuildRequires:  meson >= 0.46
# (tmb) TODO: check if any real use enabling theese
#BuildRequires:	pkgconfig(libbpf)
#BuildRequires:	pkgconfig(pwquality)

Requires(pre):	filesystem >= 2.1.9-18
Requires(pre):	shadow-utils
Requires(pre):	filesystem >= 2.1.9-18
Requires(post):	system-release
Requires(post): coreutils grep awk
Requires:	chkconfig >= 1.5

Requires:	%{libname} = %{version}-%{release}
Requires:	systemd-units = %{version}-%{release}
Requires:	dbus >= 1.3.2
Requires:	util-linux >= 2.18
Requires:	nss-myhostname
Conflicts:	initscripts < 9.78-27
Provides:	should-restart = system
Provides:  udev = %{version}-%{release}
Obsoletes: udev < 185
Provides:  u2f-hidraw-policy = 1.0.2-1
Obsoletes: u2f-hidraw-policy < 1.0.2-2
Provides:  systemd-sysvinit = %{version}-%{release}
Conflicts: systemd-sysvinit < 185
Obsoletes: systemd-sysvinit < 185
Provides:  systemd-sysv = %{version}-%{release}
Provides:  sysvinit = 2.87-22
Obsoletes: sysvinit < 2.87-22
Conflicts: SysVinit
# Due to halt/poweroff etc. in _bindir
Conflicts: usermode-consoleonly < 1:1.110
Provides:  system-logger
# (blino) consolekit has been replaced by systemd-logind
Obsoletes: consolekit
Obsoletes: consolekit-x11
Obsoletes: libconsolekit0
Obsoletes: lib64consolekit0
Obsoletes: systemd-tools
Obsoletes: gummiboot
# (tmb): systemd.pc moved to main package (mga#29894)
Conflicts: systemd-devel < 250.2-1
# (tmb) systemd-repart moved to main package
Conflicts: systemd-homed < 245-3
# Conflict with mageia-release prior to presets
Conflicts:	mageia-release < 7-0.2
# Merge back units subpkg:
Conflicts:	systemd-units <= 245.4-4.mga8
Obsoletes:      systemd-units <= 245.4-4.mga8
Provides:       systemd-units = %{version}-%{release}
# (ngompa) Provides for compatibility with Fedora/CentOS and SUSE packaging
# TODO: Consider splitting into its own subpackage to reduce the buildroot size...?
Provides:       systemd-rpm-macros = %{version}-%{release}

%description
systemd is a system and session manager for Linux, compatible with
SysV and LSB init scripts. systemd provides aggressive parallelization
capabilities, uses socket and D-Bus activation for starting services,
offers on-demand starting of daemons, keeps track of processes using
Linux cgroups, supports snapshotting and restoring of the system
state, maintains mount and automount points and implements an
elaborate transactional dependency-based service control logic. It can
work as a drop-in replacement for sysvinit.

%if %{with homed}
%package homed
Summary:	systemd homed support
Group:		System/Boot and Init
Requires:	%{name} = %{version}-%{release}

%description homed
Systemd-homed makes it easier to support migratable home directories, more
self containment within home directories, better password and encryption
handling,
%endif

%package devel
Summary:       Systemd development files
Group:         Development/C
Conflicts:     %{name} <= 35-4
Requires:      %{libname} = %{version}-%{release}
# (tv) Because of above excludes for main package:
Requires:      pkgconf-pkg-config
# (ngompa): For moving rpm macros to main package (like Fedora, openSUSE, etc.)
Conflicts: systemd < 236-1
Conflicts: systemd-devel < 236-1

%description devel
This package provides the development files for systemd.

%package tests
Summary:       Internal unit tests for systemd
Group:         Development/Other
Requires:      %{name} = %{version}-%{release}

%description tests
"Installed tests" that are usually run as part of the build system.
They can be useful to test systemd internals.


%package -n nss-myhostname
Summary:	systemd provided glibc plugin for local system host name resolution
Group:		System/Base
# (pterjan) Moved nss-systemd man pages here
Conflicts:	systemd < 236-4

%description -n nss-myhostname
nss-myhostname is a plugin for the GNU Name Service Switch (NSS)
functionality of the GNU C Library (glibc) providing host name
resolution for the locally configured system hostname as returned by
gethostname(2). Various software relies on an always resolvable local
host name. When using dynamic hostnames this is usually achieved by
patching /etc/hosts at the same time as changing the host name. This
however is not ideal since it requires a writable /etc file system and
is fragile because the file might be edited by the administrator at
the same time. nss-myhostname simply returns all locally configure
public IP addresses, or -- if none are configured -- the IPv4 address
127.0.0.2 (which is on the local loopback) and the IPv6 address ::1
(which is the local host) for whatever system hostname is configured
locally. Patching /etc/hosts is thus no longer necessary.

%package -n %{libname}
Summary:       Systemd library package
Group:         System/Libraries

%description -n %{libname}
This package provides the systemd shared library.

%package -n %{libudev}
Summary:       udev library package
Group:         System/Libraries
Requires(pre): filesystem >= 2.1.9-18

%description -n %{libudev}
This package provides the udev shared library.

%package -n %{libudev_devel}
Summary:       udev library development files
Group:         Development/C
Requires:      %{libudev} = %{version}-%{release}
Provides:      udev-devel = %{version}-%{release}
Provides:      libudev-devel = %{version}-%{release}

%description -n %{libudev_devel}
This package provides the development files for the udev shared library.


%prep
%if 0%{systemd_patch}
%autosetup -n %{name}-stable-%{version} -S git
%else
%autosetup -S git
%endif
find src/ -name "*.vala" -exec touch '{}' \;

%build
%define ntpvendor %(source /etc/os-release; echo ${ID})
%{!?ntpvendor: echo 'NTP vendor zone is not set!'; exit 1}

CONFIGURE_OPTS=(
        -Dsysvinit-path=/etc/rc.d/init.d
        -Drc-local=/etc/rc.d/rc.local
        -Ddev-kvm-mode=0666
        -Dkmod=true
        -Dxkbcommon=true
        -Dblkid=true
        -Dseccomp=true
        -Dima=true
        -Dselinux=%{?with_selinux:true}%{!?with_selinux:false}
        -Dapparmor=false
        -Dpolkit=true
        -Dxz=true
        -Dzlib=true
        -Dbzip2=true
        -Dlz4=true
        -Dpam=true
        -Dacl=true
        -Dsmack=true
        -Dgcrypt=true
        -Daudit=true
        -Delfutils=true
        -Dlibcryptsetup=true
        -Delfutils=true
        -Dqrencode=true
        -Dgnutls=true
        -Dmicrohttpd=true
        -Dlibidn2=true
        -Dlibiptc=true
        -Dlibcurl=true
        -Defi=true
%ifarch %{ix86} x86_64 aarch64
        -Dgnu-efi=true
%else
        -Dgnu-efi=false
%endif
        -Dtpm=true
        -Dhwdb=true
        -Dsysusers=true
        -Ddefault-kill-user-processes=false
        -Dtests=unsafe
        -Dinstall-tests=true
        -Dtty-gid=5
        -Dusers-gid=100
        -Dnobody-user=nobody
        -Dnobody-group=nogroup
        -Dsystem-uid-max=999
        -Dsystem-gid-max=999
        -Db_lto=true
        -Db_ndebug=false
        -Dman=true
        -Dhomed=%{?with_homed:true}%{!?with_homed:false}
	-Dpamconfdir=%{_sysconfdir}/pam.d
)

# (tv) "fix" build with gcc8:
perl -pi -e 'undef $_ if /PIE|-pie/' meson.build
%meson "${CONFIGURE_OPTS[@]}"

%meson_build

%install
%meson_install
find %{buildroot} \( -name '*.a' -o -name '*.la' \) -exec rm {} \;

# (cg) Create and ship folder to hold user rules
install -d -m 755 %{buildroot}%{_sysconfdir}/udev/rules.d

install -m 644 %SOURCE10 %{buildroot}%{_prefix}/lib/udev/rules.d/
install -m 644 %SOURCE11 %{buildroot}%{_prefix}/lib/udev/rules.d/
# udev rules for zte 3g modems and drakx-net
install -m 0644 %SOURCE12 %{buildroot}%{_prefix}/lib/udev/rules.d/

# net rules
install -m 0644 %SOURCE20 %{buildroot}%{_prefix}/lib/udev/rules.d/
install -m 0755 %SOURCE21 %{buildroot}%{_prefix}/lib/udev/net_create_ifcfg
install -m 0755 %SOURCE22 %{buildroot}%{_prefix}/lib/udev/net_action
install -m 0755 -d %{buildroot}%{_sysconfdir}/sysconfig
install -m 0644 %SOURCE23 %{buildroot}%{_sysconfdir}/sysconfig/udev_net


# Create SysV compatibility symlinks. systemctl/systemd are smart
# enough to detect in which way they are called.
mkdir -p %{buildroot}{%{_bindir},%{_sbindir}}
ln -s ../lib/systemd/systemd %{buildroot}%{_bindir}/systemd
ln -s ../bin/systemctl %{buildroot}%{_bindir}/reboot
ln -s ../bin/systemctl %{buildroot}%{_bindir}/halt
ln -s ../bin/systemctl %{buildroot}%{_bindir}/poweroff

# Also add a symlink for udevadm for now as lots of things use an absolute path
ln -s ../bin/udevadm %{buildroot}%{_sbindir}/udevadm

# (cg) To avoid making life hard for developers, don't package the
# kernel.core_pattern setting until systemd-coredump is a part of an actual
# systemd release and it's made clear how to get the core dumps out of the
# journal.
rm -f %{buildroot}%{_prefix}/lib/sysctl.d/50-coredump.conf

# Compatiblity and documentation files
touch %{buildroot}/etc/crypttab
chmod 600 %{buildroot}/etc/crypttab

# Make sure these directories are properly owned
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system/basic.target.wants
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system/default.target.wants
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system/syslog.target.wants

# And the default symlink we generate automatically based on inittab
rm -f %{buildroot}%{_sysconfdir}/systemd/system/default.target

# (bor) make sure we own directory for bluez to install service
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system/bluetooth.target.wants

touch %{buildroot}%{_localstatedir}/log/{w,b}tmp

# (cg) Set up the pager to make it generally more useful
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
cat > %{buildroot}%{_sysconfdir}/profile.d/40systemd.sh << EOF
export SYSTEMD_PAGER="/usr/bin/less -FR"
EOF
chmod 644 %{buildroot}%{_sysconfdir}/profile.d/40systemd.sh

# (bor) enable rpcbind.target by default so we have something to plug
# portmapper service into
ln -s ../rpcbind.target %{buildroot}%{_prefix}/lib/systemd/system/multi-user.target.wants

# create modules.conf as a symlink to /etc/
ln -s /etc/modules %{buildroot}%{_sysconfdir}/modules-load.d/modules.conf

# Create new-style configuration files so that we can ghost-own them
touch %{buildroot}%{_sysconfdir}/hostname
touch %{buildroot}%{_sysconfdir}/vconsole.conf
touch %{buildroot}%{_sysconfdir}/locale.conf
touch %{buildroot}%{_sysconfdir}/machine-id
touch %{buildroot}%{_sysconfdir}/machine-info
touch %{buildroot}%{_sysconfdir}/timezone
mkdir -p %{buildroot}%{_sysconfdir}/X11/xorg.conf.d
touch %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
mkdir -p %{buildroot}%{_sysconfdir}/udev/hwdb.d
touch %{buildroot}%{_sysconfdir}/udev/hwdb.bin

# (cg) Make the journal's persistent in order to provide a real syslog implementation
install -m 0755 -d %{buildroot}%{_logdir}/journal

# (cg) Default preset policy
# (for now, just a placeholder directory)
mkdir -p %{buildroot}%{_prefix}/lib/systemd/user-preset

# This file is already in systemd-ui rpm
rm -fr %{buildroot}%_mandir/man1/systemadm.*

# we already have resolvconf
rm -f %{buildroot}%{_sbindir}/resolvconf

# (cg) These are the compat libs but we don't need them in cauldron.
# All we need is the pkgconfig files so we can rebuild everything and
# kill off the need for the old library packages (which will remain installed
# and operational due to our packaging policy)
for lib in daemon id128 journal login; do
  rm -f %{buildroot}%{_libdir}/libsystemd-$lib.so{,.0.*}
done

# (ngompa) Purge links to services in /etc/systemd/system
# It *shouldn't* break anything, but if it does, we'll recreate elsewhere..
rm -rf %{buildroot}%{_sysconfdir}/systemd/system/*

%find_lang %{name}
rm -f %buildroot/usr/lib64/cryptsetup/libcryptsetup-token-systemd-tpm2.so

%if %{with check}
%check
if [ `systemd-detect-virt -c` == "systemd-nspawn" ]; then
   echo "Skipping package tests because of issues in mock nspawn containers"
   exit 0
else
   %meson_test
fi
%endif

%triggerin -- glibc
# reexec daemon on self or glibc update to avoid busy / on shutdown
# trigger is executed on both self and target install so no need to have
# extra own post
if [ $1 -ge 2 -o $2 -ge 2 ] ; then
	%{_bindir}/systemctl daemon-reexec 2>&1 || :
fi

%pre
# (cg) Cannot use rpm-helper scripts as it results in a cyclical dep as
# rpm-helper requires systemd-units which in turn requires systemd...
getent group systemd-journal &>/dev/null || groupadd -r -g 190 systemd-journal 2>&1 || :
getent group systemd-coredump &>/dev/null || groupadd -r systemd-coredump 2>&1 || :
getent passwd systemd-coredump &>/dev/null || useradd -r -l -g systemd-coredump -d / -s /sbin/nologin -c "systemd Core Dumper" systemd-coredump &>/dev/null || :
getent group systemd-network &>/dev/null || groupadd -r -g 192 systemd-network 2>&1 || :
getent passwd systemd-network &>/dev/null || useradd -r -u 192 -l -g systemd-network -d / -s /sbin/nologin -c "systemd Network Management" systemd-network &>/dev/null || :
getent group systemd-resolve &>/dev/null || groupadd -r -g 193 systemd-resolve 2>&1 || :
getent passwd systemd-resolve &>/dev/null || useradd -r -u 193 -l -g systemd-resolve -d / -s /sbin/nologin -c "systemd Resolver" systemd-resolve &>/dev/null || :


# Write on first install or upgrade from MGA3.
if [ ! -r %{_prefix}/lib/sysctl.d/50-default.conf ]; then
  if [ ! -d %{_sysconfdir}/sysctl.d ]; then
    mkdir -m 0755 %{_sysconfdir}/sysctl.d
  fi
  cat > %{_sysconfdir}/sysctl.d/51-alt-sysrq.conf << EOF
# This file ensures that the Alt+SysRq Magic keys still work.
# This setting is insecure, although commonly expected and you can remove this
# file to disable this feature. It will not be readded on future systemd
# upgrades/updates.
# https://en.wikipedia.org/wiki/Magic_SysRq_key#Security
kernel.sysrq = 1
EOF

fi

%post
%{_bindir}/systemd-machine-id-setup > /dev/null 2>&1 || :
%{_prefix}/lib/systemd/systemd-random-seed save >/dev/null 2>&1 || :

if [ $1 -eq 1 ] ; then
        # Try to read default runlevel from the old inittab if it exists
        runlevel=$(%{_bindir}/awk -F ':' '$3 == "initdefault" && $1 !~ "^#" { print $2 }' /etc/inittab 2> /dev/null)
        if [ -z "$runlevel" ] ; then
                target="%{_prefix}/lib/systemd/system/multi-user.target"
        else
                target="%{_prefix}/lib/systemd/system/runlevel$runlevel.target"
        fi

        # And symlink what we found to the new-style default.target
        %{_bindir}/ln -sf "$target" %{_sysconfdir}/systemd/system/default.target || :

        # Flag to %posttrans
        touch %{_sysconfdir}/systemd/.installing-units
fi

# (martinw) Run as posttrans as there was a circular dependency between systemd
# and systemd-units (mga#22620).
%posttrans
if [ -f  %{_sysconfdir}/systemd/.installing-units ] ; then
        rm -f %{_sysconfdir}/systemd/.installing-units

        # Enable the services we install by default.
        %{_bindir}/systemctl --quiet preset \
                remote-fs.target \
                getty@.service \
                serial-getty@.service \
                console-getty.service \
                debug-shell.service \
                systemd-timesyncd.service \
                systemd-networkd.service \
                systemd-networkd-wait-online.service \
                systemd-resolved.service \
                || :
fi

hostname_new=`cat %_sysconfdir/hostname 2>/dev/null`
if [ -z $hostname_new ]; then
        hostname_old=`cat /etc/sysconfig/network 2>/dev/null | grep HOSTNAME | cut -d "=" -f2`
        if [ ! -z $hostname_old ]; then
                echo $hostname_old >> %_sysconfdir/hostname
        else
                echo "localhost" >> %_sysconfdir/hostname
        fi
fi

%preun
if [ $1 -eq 0 ] ; then
        %{_bindir}/systemctl --quiet disable \
                getty@.service \
                remote-fs.target \
                2>&1 || :

        %{_bindir}/rm -f %_sysconfdir/systemd/system/default.target 2>&1 || :
fi

%postun
if [ $1 -ge 1 ] ; then
        %{_bindir}/systemctl daemon-reload 2>&1 || :
fi

# automatic systemd daemon reload on rpm installs/removals
%transfiletriggerin --  /usr/lib/systemd/system/ /etc/systemd/system/ /etc/init.d/ /etc/rc.d/init.d/
if [ -d %{_rundir}/systemd/system ]; then
  if [ -x %{_bindir}/systemctl ]; then
    %{_bindir}/systemctl daemon-reload >/dev/null 2>&1 || :
    %{_bindir}/systemctl reload-or-restart --marked >/dev/null 2>&1 || :
  fi
fi

%transfiletriggerpostun -P 1000100 -- /usr/lib/systemd/system /etc/systemd/system
if [ -d %{_rundir}/systemd/system ]; then
  if [ -x %{_bindir}/systemctl ]; then
    %{_bindir}/systemctl daemon-reload >/dev/null 2>&1 || :
  fi
fi

%transfiletriggerpostun -P 10000 -- /usr/lib/systemd/system /etc/systemd/system
if [ -d %{_rundir}/systemd/system ]; then
  if [ -x %{_bindir}/systemctl ]; then
    %{_bindir}/systemctl reload-or-restart --marked >/dev/null 2>&1 || :
  fi
fi

# sysusers (make sure to run before tmpfiles)
%transfiletriggerin -P 100700 -- /usr/lib/sysusers.d/
# TODO Make sysusers support --quiet
%{_bindir}/systemd-sysusers || :

# tmpfiles (make sure to run early just incase the tmpfiles created are needed by other filetriggers)
%transfiletriggerin -P 100500 --  /usr/lib/tmpfiles.d/
%{_bindir}/systemd-tmpfiles --create || :

# hwdb
%transfiletriggerin --  /usr/lib/udev/hwdb.d/
exec %{_bindir}/systemd-hwdb update

# journal catalog
%transfiletriggerin --  /usr/lib/systemd/catalog/
exec %{_bindir}/journalctl --update-catalog

%triggerpostun -- systemd-units <= 245.4-4.mga8
# fix the damage done by the obsoleted systemd-units's preun scriptlet:
/bin/systemctl enable \
        getty@.service \
        remote-fs.target

%files -f %{name}.lang
# (cg) Note some of these directories are empty, but that is intended
%dir %{_sysconfdir}/systemd
%dir %{_sysconfdir}/systemd/system
%dir %{_sysconfdir}/systemd/user
%dir %{_sysconfdir}/tmpfiles.d
%dir %{_sysconfdir}/sysctl.d
%dir %{_sysconfdir}/modules-load.d
%dir %{_sysconfdir}/binfmt.d
%dir %{_datadir}/bash-completion
%dir %{_prefix}/lib/systemd
%{_datadir}/bash-completion/completions
%{_datadir}/zsh/site-functions
%{_prefix}/lib/systemd/system
%{_prefix}/lib/systemd/system-preset
%{_prefix}/lib/systemd/user
%{_prefix}/lib/systemd/user-preset
%{_prefix}/lib/environment.d/99-environment.conf
%{_prefix}/lib/systemd/resolv.conf
%{_prefix}/lib/systemd/user-environment-generators/30-systemd-environment-d-generator
%dir %{_prefix}/lib/modprobe.d
%{_prefix}/lib/modprobe.d/README
%{_prefix}/lib/modprobe.d/systemd.conf

%ifarch %{ix86} x86_64 aarch64
%dir %{_prefix}/lib/systemd/boot
%dir %{_prefix}/lib/systemd/boot/efi
%endif
%dir %{_prefix}/lib/systemd/network
%dir %{_prefix}/lib/systemd/ntp-units.d
%dir %{_prefix}/lib/systemd/portable
%dir %{_prefix}/lib/systemd/portable/profile
%dir %{_prefix}/lib/systemd/portable/profile/default
%dir %{_prefix}/lib/systemd/portable/profile/nonetwork
%dir %{_prefix}/lib/systemd/portable/profile/strict
%dir %{_prefix}/lib/systemd/portable/profile/trusted
%dir %{_prefix}/lib/systemd/system-generators
%dir %{_prefix}/lib/systemd/system-shutdown
%dir %{_prefix}/lib/systemd/system-sleep
%dir %{_prefix}/lib/systemd/user-generators
%dir %{_tmpfilesdir}
%dir %{_prefix}/lib/sysctl.d
%dir %{_prefix}/lib/modules-load.d
%dir %{_prefix}/lib/kernel
%dir %{_prefix}/lib/kernel/install.d
%dir %{_prefix}/lib/binfmt.d
%config(noreplace) %{_sysconfdir}/sysconfig/udev_net
%config(noreplace) %{_sysconfdir}/systemd/coredump.conf
%config(noreplace) %{_sysconfdir}/systemd/journal-remote.conf
%config(noreplace) %{_sysconfdir}/systemd/journal-upload.conf
%config(noreplace) %{_sysconfdir}/systemd/journald.conf
%config(noreplace) %{_sysconfdir}/systemd/logind.conf
%config(noreplace) %{_sysconfdir}/systemd/networkd.conf
%config(noreplace) %{_sysconfdir}/systemd/pstore.conf
%config(noreplace) %{_sysconfdir}/systemd/resolved.conf
%config(noreplace) %{_sysconfdir}/systemd/sleep.conf
%config(noreplace) %{_sysconfdir}/systemd/system.conf
%config(noreplace) %{_sysconfdir}/systemd/timesyncd.conf
%config(noreplace) %{_sysconfdir}/systemd/user.conf
%config(noreplace) %{_sysconfdir}/udev/udev.conf
%{_sysconfdir}/modules-load.d/modules.conf
%{_sysconfdir}/profile.d/40systemd.sh
%dir %{_sysconfdir}/udev/
%dir %{_sysconfdir}/udev/hwdb.d/
%ghost %{_sysconfdir}/udev/hwdb.bin
%{_sysusersdir}/systemd-coredump.conf
%{_sysusersdir}/systemd-journal.conf
%{_sysusersdir}/systemd-network.conf
%{_sysusersdir}/systemd-oom.conf
%{_sysusersdir}/systemd-resolve.conf
%{_sysusersdir}/systemd-timesync.conf
%{_sysconfdir}/xdg/systemd
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/crypttab
%ghost %config(noreplace) %{_sysconfdir}/hostname
%ghost %config(noreplace) %{_sysconfdir}/vconsole.conf
%ghost %config(noreplace) %{_sysconfdir}/locale.conf
%ghost %config(noreplace) %{_sysconfdir}/machine-id
%ghost %config(noreplace) %{_sysconfdir}/machine-info
%ghost %config(noreplace) %{_sysconfdir}/timezone
%ghost %config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
%ghost %attr(0664,root,utmp) /var/log/btmp
%ghost %attr(0664,root,utmp) /var/log/wtmp
# (cg) NB dbus policy files are not really config that users are expected to
# edit manually and thus should NOT be marked as config(noreplace).
# This should really be fixed in upstream dbus (work in progress)
# to separate these policy files from /etc and ship them in /usr instead
# but allow override by admins by copying to /etc.
# There are security implications here (CVE's have been issued due to mistakes
# in these type of files)
%{_datadir}/dbus-1/interfaces/org.freedesktop.LogControl1.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.hostname1.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.import1.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.import1.Transfer.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.locale1.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.login1.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.login1.Seat.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.login1.Session.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.login1.User.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.machine1.Image.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.machine1.Machine.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.machine1.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.network1.DHCPServer.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.network1.Link.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.network1.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.network1.Network.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.oom1.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portable1.Image.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portable1.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.resolve1.DnssdService.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.resolve1.Link.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.resolve1.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Automount.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Device.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Job.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Mount.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Path.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Scope.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Service.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Slice.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Socket.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Swap.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Target.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Timer.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.Unit.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.timedate1.xml
%{_datadir}/dbus-1/system.d/org.freedesktop.hostname1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.import1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.locale1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.login1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.machine1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.network1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.portable1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.resolve1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.systemd1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.timedate1.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.timesync1.conf
%{_sysconfdir}/pam.d/%{name}-user
%dir %{_sysconfdir}/udev/rules.d
%{_sysconfdir}/X11/xinit/xinitrc.d/50-systemd-user.sh
%ifarch %{ix86} x86_64 aarch64
%{_prefix}/lib/systemd/boot/efi/linux*.efi.stub
%{_prefix}/lib/systemd/boot/efi/linux*.elf.stub
%{_prefix}/lib/systemd/boot/efi/systemd-boot*.efi
%{_prefix}/lib/systemd/ukify
%endif
%{_prefix}/lib/systemd/import-pubring.gpg
%{_prefix}/lib/systemd/network/80-6rd-tunnel.network
%{_prefix}/lib/systemd/network/80-container-host0.network
%{_prefix}/lib/systemd/network/80-container-vb.network
%{_prefix}/lib/systemd/network/80-container-ve.network
%{_prefix}/lib/systemd/network/80-container-vz.network
%{_prefix}/lib/systemd/network/80-ethernet.network.example
%{_prefix}/lib/systemd/network/80-vm-vt.network
%{_prefix}/lib/systemd/network/80-wifi-adhoc.network
%{_prefix}/lib/systemd/network/80-wifi-ap.network.example
%{_prefix}/lib/systemd/network/80-wifi-station.network.example
%{_prefix}/lib/systemd/network/99-default.link
%{_prefix}/lib/systemd/ntp-units.d/80-systemd-timesync.list
%{_prefix}/lib/systemd/portable/profile/default/service.conf
%{_prefix}/lib/systemd/portable/profile/nonetwork/service.conf
%{_prefix}/lib/systemd/portable/profile/strict/service.conf
%{_prefix}/lib/systemd/portable/profile/trusted/service.conf
%{_prefix}/lib/sysctl.d/README
# (cg) NB See pre script for soemthing that relies on this name...
# If it is ever renamed, change the pre script too
%{_prefix}/lib/sysctl.d/50-default.conf
%ifarch x86_64 aarch64
%{_prefix}/lib/sysctl.d/50-pid-max.conf
%endif
%{_sysusersdir}/README
%{_sysusersdir}/basic.conf
%{_sysusersdir}/systemd-remote.conf
%{_tmpfilesdir}/README
%{_tmpfilesdir}/credstore.conf
%{_tmpfilesdir}/etc.conf
%{_tmpfilesdir}/home.conf
%{_tmpfilesdir}/journal-nocow.conf
%{_tmpfilesdir}/legacy.conf
%{_tmpfilesdir}/portables.conf
%{_tmpfilesdir}/provision.conf
%{_tmpfilesdir}/static-nodes-permissions.conf
%{_tmpfilesdir}/systemd.conf
%{_tmpfilesdir}/systemd-network.conf
%{_tmpfilesdir}/systemd-nologin.conf
%{_tmpfilesdir}/systemd-nspawn.conf
%{_tmpfilesdir}/systemd-pstore.conf
%{_tmpfilesdir}/systemd-resolve.conf
%{_tmpfilesdir}/systemd-tmp.conf
%{_tmpfilesdir}/tmp.conf
%{_tmpfilesdir}/var.conf
%{_tmpfilesdir}/x11.conf
%{_prefix}/lib/kernel/install.conf
%{_prefix}/lib/kernel/install.d/50-depmod.install
%{_prefix}/lib/kernel/install.d/90-loaderentry.install
%{_prefix}/lib/kernel/install.d/90-uki-copy.install
%ifnarch %{arm}
%{_bindir}/bootctl
%endif
%{_bindir}/busctl
%{_bindir}/coredumpctl
%{_bindir}/halt
%{_bindir}/hostnamectl
%{_bindir}/journalctl
%{_bindir}/kernel-install
%{_bindir}/localectl
%{_bindir}/loginctl
%{_bindir}/machinectl
%{_bindir}/networkctl
%{_bindir}/oomctl
%{_bindir}/systemd-ac-power
%{_bindir}/systemd-creds
%{_bindir}/systemd-dissect
%{_bindir}/portablectl
%{_bindir}/poweroff
%{_bindir}/reboot
%{_bindir}/resolvectl
%{_bindir}/systemd
%{_bindir}/systemd-ask-password
%{_bindir}/systemd-cryptenroll
%{_bindir}/systemd-escape
%{_bindir}/systemd-firstboot
%{_bindir}/systemd-hwdb
%{_bindir}/systemd-id128
%{_bindir}/systemd-inhibit
%{_bindir}/systemd-machine-id-setup
%{_bindir}/systemd-mount
%{_bindir}/systemd-notify
%{_bindir}/systemd-path
%{_bindir}/systemd-run
%{_bindir}/systemd-resolve
%{_bindir}/systemd-sysext
%{_bindir}/systemd-sysusers
%{_bindir}/systemd-tmpfiles
%{_bindir}/systemd-tty-ask-password-agent
%{_bindir}/systemd-umount
%{_bindir}/timedatectl
%{_bindir}/userdbctl
%{_sbindir}/halt
%{_sbindir}/init
%{_sbindir}/poweroff
%{_sbindir}/reboot
%{_sbindir}/runlevel
%{_sbindir}/shutdown
%{_sbindir}/telinit
%{_sbindir}/udevadm
%{_prefix}/lib/systemd/systemd*
%{_prefix}/lib/systemd/system-generators/systemd-*
%{_prefix}/lib/systemd/user-generators/systemd-*
%{_prefix}/lib/udev
%{_libdir}/cryptsetup/libcryptsetup-token-systemd-pkcs11.so
%{_libdir}/security/pam_systemd.so
%{_libdir}/systemd/libsystemd-core-%{systemd_branch}.so
%{_libdir}/systemd/libsystemd-shared-%{systemd_branch}.so
%{_bindir}/systemctl
%{_bindir}/systemd-analyze
%{_bindir}/systemd-cat
%{_bindir}/systemd-cgls
%{_bindir}/systemd-cgtop
%{_bindir}/systemd-delta
%{_bindir}/systemd-detect-virt
%{_bindir}/systemd-nspawn
%{_bindir}/systemd-repart
%{_bindir}/systemd-socket-activate
%{_bindir}/systemd-stdio-bridge
%{_bindir}/udevadm
%dir %{_datadir}/systemd
%{_datadir}/systemd/kbd-model-map
%{_datadir}/systemd/language-fallback-map
%dir %{_datadir}/systemd/gatewayd
%{_datadir}/systemd/gatewayd/browse.html
%{_datadir}/dbus-1/system-services/org.freedesktop.oom1.service
%{_datadir}/dbus-1/system.d/org.freedesktop.oom1.conf
%ifnarch %{arm}
%{_mandir}/man1/bootctl.*
%{_mandir}/man1/ukify.*
%endif
%{_mandir}/man1/busctl.*
%{_mandir}/man1/coredumpctl.*
%{_mandir}/man1/hostnamectl.*
%{_mandir}/man1/init.*
%{_mandir}/man1/journalctl.*
%{_mandir}/man1/localectl.*
%{_mandir}/man1/loginctl.*
%{_mandir}/man1/machinectl.*
%{_mandir}/man1/networkctl.*
%{_mandir}/man1/portablectl.*
%{_mandir}/man1/resolvconf.*
%{_mandir}/man1/resolvectl.*
%{_mandir}/man1/systemctl.*
%{_mandir}/man1/systemd.*
%{_mandir}/man1/systemd-*
%{_mandir}/man1/timedatectl.*
%{_mandir}/man1/userdbctl.1.*
%{_mandir}/man1/oomctl.1.*
%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man7/*
%{_mandir}/man8/30-systemd-environment-d-generator.8.*
%{_mandir}/man8/halt.*
%{_mandir}/man8/kernel-install.*
%{_mandir}/man8/shutdown.*
%{_mandir}/man8/pam_systemd.*
%{_mandir}/man8/poweroff.*
%{_mandir}/man8/rc-local.service.*
%{_mandir}/man8/reboot.*
%{_mandir}/man8/runlevel.*
%{_mandir}/man8/systemd-*
%{_mandir}/man8/telinit.*
%{_mandir}/man8/udevadm.*
%{_sysconfdir}/rc.d/init.d/README
%{_sysconfdir}/systemd/oomd.conf
%{_datadir}/dbus-1/services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.hostname1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.import1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.locale1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.login1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.machine1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.network1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.portable1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.resolve1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.timedate1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.timesync1.service
%dir %{_datadir}/factory
%dir %{_datadir}/factory/etc
%{_datadir}/factory/etc/issue
%{_datadir}/factory/etc/locale.conf
%{_datadir}/factory/etc/nsswitch.conf
%dir %{_datadir}/factory/etc/pam.d
%{_datadir}/factory/etc/pam.d/other
%{_datadir}/factory/etc/pam.d/system-auth
# For allowing applications to find systemd runtime paths (mga#29894)
%{_datadir}/pkgconfig/systemd.pc
%{_datadir}/polkit-1/actions/org.freedesktop.systemd1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.hostname1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.import1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.locale1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.login1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.machine1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.network1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.portable1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.resolve1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.timedate1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.timesync1.policy
%{_datadir}/polkit-1/rules.d/systemd-networkd.rules
%{_docdir}/systemd
%{_prefix}/lib/systemd/catalog/systemd.catalog
# For RPM packages to utilize standard systemd runtime macros
%{_prefix}/lib/rpm/macros.d/macros.systemd
%lang(be) %{_prefix}/lib/systemd/catalog/systemd.be.catalog
%lang(be@latin) %{_prefix}/lib/systemd/catalog/systemd.be@latin.catalog
%lang(bg) %{_prefix}/lib/systemd/catalog/systemd.bg.catalog
%lang(da) %{_prefix}/lib/systemd/catalog/systemd.da.catalog
%lang(de) %{_prefix}/lib/systemd/catalog/systemd.de.catalog
%lang(fr) %{_prefix}/lib/systemd/catalog/systemd.fr.catalog
%lang(hr) %{_prefix}/lib/systemd/catalog/systemd.hr.catalog
%lang(hu) %{_prefix}/lib/systemd/catalog/systemd.hu.catalog
%lang(it) %{_prefix}/lib/systemd/catalog/systemd.it.catalog
%lang(ko) %{_prefix}/lib/systemd/catalog/systemd.ko.catalog
%lang(pl) %{_prefix}/lib/systemd/catalog/systemd.pl.catalog
%lang(pt_BR) %{_prefix}/lib/systemd/catalog/systemd.pt_BR.catalog
%lang(ru) %{_prefix}/lib/systemd/catalog/systemd.ru.catalog
%lang(sr) %{_prefix}/lib/systemd/catalog/systemd.sr.catalog
%lang(zh_CN) %{_prefix}/lib/systemd/catalog/systemd.zh_CN.catalog
%lang(zh_TW) %{_prefix}/lib/systemd/catalog/systemd.zh_TW.catalog
%attr(02755,root,systemd-journal) %dir %{_logdir}/journal

%if %{with homed}
%files homed
%{_bindir}/homectl
%{_libdir}/security/pam_systemd_home.so
%{_datadir}/dbus-1/interfaces/org.freedesktop.home1.Home.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.home1.Manager.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.home1.service
%{_datadir}/dbus-1/system.d/org.freedesktop.home1.conf
%{_datadir}/polkit-1/actions/org.freedesktop.home1.policy
%{_mandir}/man1/homectl.1.*
%{_mandir}/man8/pam_systemd_home.8.*
%config(noreplace) %{_sysconfdir}/systemd/homed.conf
%endif

%files devel
%{_includedir}/systemd
%{_libdir}/libsystemd*.so
%{_libdir}/pkgconfig/libsystemd*.pc

%files tests
%{_prefix}/lib/systemd/tests/

%files -n nss-myhostname
%{_mandir}/man8/nss-myhostname.*
%{_mandir}/man8/libnss_myhostname.so.2.*
%{_libdir}/libnss_myhostname.so.2
# (cg) Yes, this is a hack for now, I'll likely rename the package to just lib[64]systemd-nss2 or something...
%{_mandir}/man8/nss-mymachines.*
%{_mandir}/man8/libnss_mymachines.so.2.*
%{_libdir}/libnss_mymachines.so.2
%{_mandir}/man8/nss-resolve.*
%{_mandir}/man8/libnss_resolve.so.2.*
%{_libdir}/libnss_resolve.so.2
%{_mandir}/man8/nss-systemd.8.*
%{_mandir}/man8/libnss_systemd.so.2.*
%{_libdir}/libnss_systemd.so.2

%files -n %{libname}
%{_libdir}/libsystemd.so.%{libsystemd_major}{,.*}

%files -n %{libudev}
%{_libdir}/libudev.so.%{libudev_major}{,.*}

%files -n %{libudev_devel}
%{_libdir}/libudev.so
%{_includedir}/libudev.h
%{_datadir}/pkgconfig/udev.pc
%{_libdir}/pkgconfig/libudev.pc


%changelog
* Thu Feb 22 2024 kekepower <kekepower> 253.16-1.mga9
+ Revision: 2043195
- Update to version 253.16 (mga#32883)
- Add pam_limits.so to systemd-user (mga#32201)
- Include patch from rapsys
 o Add patch fixing systemd-vconsole-setup[X]: Failed to import credentials, ignoring: No such file or directory
 o Source: https://github.com/systemd/systemd/commit/55ace8e5c58441d1a2c64b297a38b232ef0c0e28
- Bump to subrel 1 for fix from rapsys
+ rapsys <rapsys>
- Add patch fixing systemd-vconsole-setup[X]: Failed to import credentials, ignoring: No such file or directory
  Source: https://github.com/systemd/systemd/commit/55ace8e5c58441d1a2c64b297a38b232ef0c0e28
+ tmb <tmb>
- update to v253.10
- update to v253.9
- update to v253.8

* Wed Jul 19 2023 tmb <tmb> 253.7-1.mga9
+ Revision: 1964017
- update to v253.7

* Sat Jun 03 2023 wally <wally> 253.5-2.mga9
+ Revision: 1960611
- create and own local hwdb administration directory /etc/udev/hwdb.d/

* Fri Jun 02 2023 tmb <tmb> 253.5-1.mga9
+ Revision: 1960588
- update to v253.5

* Wed May 03 2023 tmb <tmb> 253.4-1.mga9
+ Revision: 1955682
- update to v253.4

* Thu Apr 20 2023 tmb <tmb> 253.3-2.mga9
+ Revision: 1953712
- update filelist for arm

* Thu Apr 20 2023 tmb <tmb> 253.3-1.mga9
+ Revision: 1953711
- update to v253.3

* Sat Apr 08 2023 tmb <tmb> 252.9-1.mga9
+ Revision: 1951761
- update to v252.9

* Fri Mar 31 2023 tmb <tmb> 252.8-1.mga9
+ Revision: 1950959
- update to v252.8

* Sat Mar 04 2023 tmb <tmb> 252.7-1.mga9
+ Revision: 1947603
- update to v252.7

* Sat Feb 25 2023 tmb <tmb> 252.6-1.mga9
+ Revision: 1945295
- update filelists
- update to v252.6

* Sun Jan 29 2023 tmb <tmb> 252.5-1.mga9
+ Revision: 1936877
- update to v252.5

* Sun Jan 22 2023 tmb <tmb> 252.4-2.mga9
+ Revision: 1934831
- silence warning about missing native systemd service files

* Thu Dec 22 2022 tmb <tmb> 252.4-1.mga9
+ Revision: 1925633
- update to v252.4

* Sat Dec 10 2022 tmb <tmb> 252.3-1.mga9
+ Revision: 1920467
- update to v252.3

* Sat Nov 26 2022 tmb <tmb> 252.2-1.mga9
+ Revision: 1911531
- update to v252.2

* Tue Nov 08 2022 tmb <tmb> 252.1-1.mga9
+ Revision: 1904765
- update to v252.1

* Sat Nov 05 2022 tmb <tmb> 252-2.mga9
+ Revision: 1903698
- add fixes from upstream v252-stable branch

* Sat Nov 05 2022 tmb <tmb> 252-1.mga9
+ Revision: 1903690
- update to v252

* Fri Oct 28 2022 tmb <tmb> 251.7-1.mga9
+ Revision: 1899934
- update to v251.7

* Sat Oct 22 2022 tmb <tmb> 251.6-1.mga9
+ Revision: 1898340
- update v251.6

* Sun Oct 02 2022 tmb <tmb> 251.5-1.mga9
+ Revision: 1893777
- update to v251.5

* Wed Aug 10 2022 tmb <tmb> 251.4-1.mga9
+ Revision: 1876580
- update to v251.4

* Fri Jul 15 2022 tmb <tmb> 251.3-1.mga9
+ Revision: 1869137
- update to v251.3

* Wed Jun 08 2022 tv <tv> 251.2-2.mga9
+ Revision: 1863610
- prevent pulling pkgconfig in basesystem (side effect of "move systemd.pc
  pkg-config file to main package (mga#29894)")

* Sun Jun 05 2022 tmb <tmb> 251.2-1.mga9
+ Revision: 1861313
- sha256: fix compilation on efi-ia32
- update to v251.2

* Thu May 26 2022 tmb <tmb> 251.1-1.mga9
+ Revision: 1860335
- update to v251.1

* Tue May 24 2022 tmb <tmb> 251-1.mga9
+ Revision: 1860013
- coredump: Fix format string type mismatch
- update to v251
- update filelists

* Thu Apr 28 2022 tmb <tmb> 250.5-1.mga9
+ Revision: 1854980
- update to v250.5

* Thu Mar 24 2022 umeabot <umeabot> 250.4-2.mga9
+ Revision: 1824137
- Mageia 9 Mass Rebuild

* Sat Mar 19 2022 tmb <tmb> 250.4-1.mga9
+ Revision: 1799992
- update to v250.4

* Thu Mar 03 2022 tmb <tmb> 250.3-4.mga9
+ Revision: 1788163
- rebuild with gcc 12

* Thu Feb 17 2022 tmb <tmb> 250.3-3.mga9
+ Revision: 1779480
- rebuild with glibc 2.35-3

* Sat Feb 12 2022 tmb <tmb> 250.3-2.mga9
+ Revision: 1773195
- rebuild with glibc 2.35

* Thu Jan 20 2022 tmb <tmb> 250.3-1.mga9
+ Revision: 1769197
- update to v250.3

* Sun Jan 16 2022 tmb <tmb> 250.2-1.mga9
+ Revision: 1768733
- aarch64: enable gnu-efi support
- move systemd.pc pkg-config file to main package (mga#29894)
- update filelists
- rebase P508, P512
- update to v250.2

* Wed Jan 12 2022 tmb <tmb> 249.8-1.mga9
+ Revision: 1768125
- update to 249.8 (CVE-2021-3997, mga#29864)

* Sat Nov 20 2021 tmb <tmb> 249.7-1.mga9
+ Revision: 1758121
- update to v249.7

* Sun Nov 14 2021 tmb <tmb> 249.6-1.mga9
+ Revision: 1756498
- update to v249.6
+ wally <wally>
- enable pcre2 support

* Fri Nov 05 2021 tmb <tmb> 249.5-2.mga9
+ Revision: 1754000
- Revert "core: Check unit start rate limiting earlier"
- sd-dhcp6-client: ignore IAs whose IAID do not match client's IAID
- sd-boot: Unify error handling
- sd-boot: Rework console input handling

* Sat Oct 16 2021 tmb <tmb> 249.5-1.mga9
+ Revision: 1751786
- coredumpctl: stop truncating information about coredump
- update to v249.5

* Sat Oct 02 2021 wally <wally> 249.4-5.mga9
+ Revision: 1748101
- rebuild for openssl 3.0.0

* Fri Oct 01 2021 tmb <tmb> 249.4-4.mga9
+ Revision: 1747305
- rebuild for openssl 3.0.0

* Sun Sep 26 2021 tmb <tmb> 249.4-3.mga9
+ Revision: 1746460
- rebuild with fixed glibc-2.34-5.mga9
- rebuild with glibc 2.34

* Thu Sep 02 2021 tmb <tmb> 249.4-1.mga9
+ Revision: 1743993
- update to v249.4

* Fri Aug 06 2021 tmb <tmb> 249.3-1.mga9
+ Revision: 1739951
- update to v249.3

* Wed Jul 28 2021 tmb <tmb> 249.2-1.mga9
+ Revision: 1738030
- update to 249.2

* Tue Jul 20 2021 tmb <tmb> 249.1-2.mga9
+ Revision: 1737202
- rebuild with binutils 2.37

* Tue Jul 20 2021 tmb <tmb> 249.1-1.mga9
+ Revision: 1737200
- update to v249.1

* Tue Jul 20 2021 tmb <tmb> 249-5.mga9
+ Revision: 1737175
- rebuild with binutils 2.37

* Sun Jul 11 2021 wally <wally> 249-4.mga9
+ Revision: 1735659
- reload or restart services marked for such after pkg installs

* Sat Jul 10 2021 tmb <tmb> 249-3.mga9
+ Revision: 1735629
- hostnamed: correct variable with errno in fallback_chassis

* Thu Jul 08 2021 tmb <tmb> 249-2.mga9
+ Revision: 1735147
- re-enable P502

* Thu Jul 08 2021 tmb <tmb> 249-1.mga9
+ Revision: 1735146
- update to v249

* Wed May 19 2021 tmb <tmb> 248.3-1.mga9
+ Revision: 1725695
- update to v248.3

* Sat May 08 2021 tmb <tmb> 248.2-1.mga9
+ Revision: 1722307
- update to v248.2
  * drop merged patches

* Fri Apr 30 2021 tmb <tmb> 248-4.mga9
+ Revision: 1720512
- core: allow services stuck in reloading state to exit
- systemd-coredump: Add conflict with shutdown.target
- systemd-networkd.socket: Add conflict with shutdown.target (#19348)

* Sun Apr 25 2021 wally <wally> 248-3.mga9
+ Revision: 1719360
- rfkill: add some casts to silence -Werror=sign-compare
+ tmb <tmb>
- rebuild with gcc 11.1

* Wed Apr 07 2021 tmb <tmb> 248-2.mga9
+ Revision: 1714052
- LoadCredentials: do not assert on invalid syntax

* Sun Apr 04 2021 tmb <tmb> 248-1.mga9
+ Revision: 1713222
- update to v248

* Sat Mar 27 2021 tmb <tmb> 247.6-1.mga9
+ Revision: 1710939
- update to v247.6

* Thu Mar 18 2021 tmb <tmb> 247.4-1.mga9
+ Revision: 1704222
- update to v247.4

* Mon Mar 08 2021 ghibo <ghibo> 247.3-2.mga9
+ Revision: 1700623
- Execute 50-systemd-user.sh as "sourced" in X11 xinit(s) to avoid zombie creation (as of bug #27362).

* Sun Mar 07 2021 tmb <tmb> 247.3-1.mga9
+ Revision: 1700535
- update to 247.3

* Sat Mar 06 2021 tmb <tmb> 246.10-1.mga9
+ Revision: 1700215
- update to v246.10
- resolved: gracefully handle with packets with too large RR count

* Wed Mar 03 2021 tmb <tmb> 246.9-7.mga9
+ Revision: 1697147
- rebuild with new glibc / binutils

* Thu Feb 25 2021 neoclust <neoclust> 246.9-6.mga9
+ Revision: 1691075
- Add systemd-sysv as a provide

* Sat Feb 13 2021 tmb <tmb> 246.9-5.mga8
+ Revision: 1675246
- udev: drop Iomega Zip rule that uses invalid option 'all_partitions' (mga#26718)

* Sun Jan 31 2021 tmb <tmb> 246.9-4.mga8
+ Revision: 1674209
- rebuild with new binutils / gcc

* Sun Jan 03 2021 tmb <tmb> 246.9-2.mga8
+ Revision: 1668517
- silence warning about missing native systemd service file

* Fri Dec 25 2020 tmb <tmb> 246.9-1.mga8
+ Revision: 1663672
- update to v246.9 in /release

* Fri Dec 25 2020 joequant <joequant> 247.2-1.mga8
+ Revision: 1663643
- update to 247.2

* Sat Dec 12 2020 tmb <tmb> 246.7-1.mga8
+ Revision: 1655841
- update to v246.7

* Sun Nov 22 2020 tmb <tmb> 246.6-2.mga8
+ Revision: 1648487
- testbuild with glibc 2.32

* Sun Sep 20 2020 kekepower <kekepower> 246.6-1.mga8
+ Revision: 1628959
- Update to version 246.6

* Sun Sep 13 2020 kekepower <kekepower> 246.5-1.mga8
+ Revision: 1625895
- Update to version 246.5

* Thu Sep 03 2020 kekepower <kekepower> 246.4-1.mga8
+ Revision: 1621255
- Update to version 246.4

* Wed Aug 19 2020 kekepower <kekepower> 246.2-1.mga8
+ Revision: 1615883
- Update to version 246.2

* Sat Aug 08 2020 luigiwalser <luigiwalser> 246.1-2.mga8
+ Revision: 1611962
- obsolete u2f-hidraw-policy (rhbz#1753381)

* Fri Aug 07 2020 kekepower <kekepower> 246.1-1.mga8
+ Revision: 1611946
- Update to version 246.1

* Mon Aug 03 2020 ovitters <ovitters> 246-3.mga8
+ Revision: 1610768
- move ownership of /var/log/{wtmp,btmp} from initscripts to systemd

* Sat Aug 01 2020 ovitters <ovitters> 246-2.mga8
+ Revision: 1610428
- move ownership of /etc/crypttab from initscripts to systemd

* Fri Jul 31 2020 kekepower <kekepower> 246-1.mga8
+ Revision: 1609995
- Update to version 246

* Mon Jul 27 2020 kekepower <kekepower> 245.7-1.mga8
+ Revision: 1609319
- Update to version 245.7

* Thu Jul 09 2020 kekepower <kekepower> 245.6-3.mga8
+ Revision: 1603494
- Add 2 upstream patches to fix CVE-2020-13776
- Add patch to fix building with microhttp 0.9.71

* Sat Jun 06 2020 wally <wally> 245.6-2.mga8
+ Revision: 1590753
- fix and update transfiletriggerin to reload the daemon after pkg installs

* Wed Jun 03 2020 kekepower <kekepower> 245.6-1.mga8
+ Revision: 1590149
- Update to version 245.6

* Thu May 07 2020 tmb <tmb> 245.5-4.mga8
+ Revision: 1581579
- rebuild with gcc 10.1 final

* Mon May 04 2020 tmb <tmb> 245.5-2.mga8
+ Revision: 1579652
- rebuild with gcc 10.1

* Tue Apr 21 2020 tmb <tmb> 245.5-1.mga8
+ Revision: 1570450
- update to 245.5
+ tv <tv>
- remove very old obsolte on prcsys

* Thu Apr 16 2020 tv <tv> 245.4-5.mga8
+ Revision: 1567916
- Merge -units into the main package
- Add triggers from to prevent the damage done by the obsoleted
  systemd-units's preun scriptlet (rhbz#807457)
- remove triggers against old mga[45] versions

* Thu Apr 16 2020 joequant <joequant> 245.4-4.mga8
+ Revision: 1567831
- remove systemd systemd-units circular dependency

* Wed Apr 15 2020 joequant <joequant> 245.4-3.mga8
+ Revision: 1567641
- remove circular dependency with initscripts

* Sun Apr 12 2020 wally <wally> 245.4-2.mga8
+ Revision: 1566906
- add patch to remove trailing space from rpm macros using SYSTEM_INLINE_EOF

* Thu Apr 02 2020 tmb <tmb> 245.4-1.mga8
+ Revision: 1564032
- update to 245.4

* Fri Mar 20 2020 tmb <tmb> 245.2-1.mga8
+ Revision: 1558201
- update to 245.2

* Sun Mar 08 2020 tmb <tmb> 245-4.mga8
+ Revision: 1554983
- boot: Ensure ARM UEFI binary does not contain FP/SIMD instructions

* Sun Mar 08 2020 tmb <tmb> 245-3.mga8
+ Revision: 1554756
- move systemd-repart to main package (mga#26317)

* Sat Mar 07 2020 tmb <tmb> 245-2.mga8
+ Revision: 1554627
- enable homed support as separate package to be able to experiment with it

* Sat Mar 07 2020 tmb <tmb> 245-1.mga8
+ Revision: 1554609
- update to v245
  * drop merged patches
  * update filelists
  * rebase Mageia patches

* Wed Feb 19 2020 umeabot <umeabot> 241-17.mga8
+ Revision: 1542570
- Mageia 8 Mass Rebuild
+ tmb <tmb>
- Be more specific in resolved.conf man page with regard to DNSOverTLS
- add notes for CVE-2019-20386 and CVE-2020-1712

* Thu Feb 13 2020 tmb <tmb> 241-16.mga8
+ Revision: 1514229
- add fixes from upstream v241-stable branch

* Thu Feb 13 2020 tmb <tmb> 241-15.mga8
+ Revision: 1514188
- rebuild for new glibc

* Mon Jan 06 2020 tmb <tmb> 241-14.mga8
+ Revision: 1476772
- rebuild for new iptables

* Sat Nov 09 2019 tmb <tmb> 241-12.mga8
+ Revision: 1458928
- seccomp: add new 5.1 syscall pidfd_send_signal() to filter set list
- seccomp: add new Linux 5.3 syscalls to syscall filter lists
- seccomp: add all *time64 syscalls
- Add @pkey syscall group
- add fixes from upstream v241-stable branch

* Wed Aug 14 2019 tmb <tmb> 241-10.mga8
+ Revision: 1429297
- add fixes v241-stable

* Mon Jul 08 2019 tmb <tmb> 241-9.mga8
+ Revision: 1419665
- random-util: eat up bad RDRAND values seen on AMD CPUs
- udevd: fix a reversed conditional on global property set (mga#25027)

* Sat Apr 27 2019 tmb <tmb> 241-8.mga7
+ Revision: 1395748
- add fixes from upstream v241 stable branch

* Sun Apr 21 2019 tmb <tmb> 241-7.mga7
+ Revision: 1394519
- disable NDEBUG

* Sun Apr 21 2019 tmb <tmb> 241-6.mga7
+ Revision: 1394518
- fstab-generator: use DefaultDependencies=no for /sysroot mounts
- nss-resolve: return error properly
- nss-mymachines: return NO_RECOVERY instead of NO_DATA when we fail
  to do D-Bus and similar
- nss-resolve: list more errors as cause for fallback

* Thu Apr 18 2019 umeabot <umeabot> 241-5.mga7
+ Revision: 1392933
- Rebuild with meson 0.50.1

* Wed Apr 10 2019 tmb <tmb> 241-4.mga7
+ Revision: 1388189
- more fixes from upstream v241-stable branch

* Fri Apr 05 2019 tmb <tmb> 241-3.mga7
+ Revision: 1386046
- add fixes from upstream v241-stable branch

* Mon Mar 18 2019 tmb <tmb> 241-2.mga7
+ Revision: 1378705
- login: mark nokmsboot fb devices as master-of-seat
- fixes from v241-stable branch
  * sd-device: also store properties read from udev database to
    sd_device::properties_db
  * udev-event: make subst_format_var() always provide null-terminated
    string on success
  * login: HyperV requires master-of-seat to be set
  * login: mark nomodeset fb devices as master-of-seat

* Sat Feb 23 2019 tmb <tmb> 241-1.mga7
+ Revision: 1369554
- rebuild with gcc 8.3.0 final
-  CVE-2019-6454: systemd (PID1) crash with specially crafted D-Bus message

* Thu Feb 14 2019 tmb <tmb> 241-0.2.mga7
+ Revision: 1367089
- dont ship /sbin/resolvconf

* Thu Feb 14 2019 tmb <tmb> 241-0.1.mga7
+ Revision: 1367074
- update filelists
- disable python bytecompiling for now
- disable P506, P507, P510
- rebase P509
- drop merged patches
- update to v241

* Wed Feb 13 2019 luigiwalser <luigiwalser> 236-14.mga7
+ Revision: 1366532
- rebuild for libidn2

* Sun Jan 13 2019 martinw <martinw> 236-13.mga7
+ Revision: 1355897
- only run preset on units when installing

* Sat Jan 12 2019 martinw <martinw> 236-12.mga7
+ Revision: 1355727
- fix preset of standard services (mga#22620)
  o use %%posttrans to work round systemd|systemd-units circular dependency
  o don't preset console-shell service - it no longer exists
  o don't hide error messages - we need to know if this fails

* Wed Jan 09 2019 wally <wally> 236-11.mga7
+ Revision: 1353672
- backport upstream patch to fix build with new meson
- rebuild for new libidn2
+ tmb <tmb>
- dhcp6: make sure we have enough space for the DHCP6 option header
  (CVE-2018-15688)
+ tv <tv>
- util-linux-ng -> util-linux

* Mon Sep 03 2018 tv <tv> 236-9.mga7
+ Revision: 1256756
- "fix" build with gcc8:
- drop requires on lockdev

* Sat May 26 2018 tmb <tmb> 236-7.mga7
+ Revision: 1232291
- core: don't include libmount.h in a header file (#8580)
- fix systemd redefining reserved word
- add upstream fixes for new glibc
- rebuild for new glibc

* Wed Mar 14 2018 kekepower <kekepower> 236-6.mga7
+ Revision: 1209541
- Rebuild for new cryptsetup, second attempt

* Wed Mar 14 2018 kekepower <kekepower> 236-5.mga7
+ Revision: 1209393
- Rebuild for new cryptsetup

* Tue Jan 09 2018 pterjan <pterjan> 236-4.mga7
+ Revision: 1191867
- Move some files around (mga#22350)

* Sat Jan 06 2018 ngompa <ngompa> 236-3.mga7
+ Revision: 1190928
- Backport patch to fix mounting encrypted volumes
- Backport patch to fix systemd-analyze plot
- Disable SELinux integration as PAM and other dependent components have it disabled

* Sat Jan 06 2018 ngompa <ngompa> 236-2.mga7
+ Revision: 1190635
- Bump release fix build
- New version 236
- Drop legacy Obsoletes+Provides in devel subpackages
- Move systemd.pc back to devel subpackage to avoid pkgconfig runtime dependency
- Drop prefdm bits as prefdm is gone
- Move rpm macros and systemd.pc to main package (consistent with other distros)
+ neoclust <neoclust>
- New version 235
- New version 234 ( remove merged patches )
+ wally <wally>
- switch to libidn2
+ daviddavid <daviddavid>
- rebuild for new qrencode 4.0.0

* Thu Jun 29 2017 tmb <tmb> 230-12.mga6
+ Revision: 1108690
- resolved: simplify alloc size calculation (CVE-2017-9445, mga#21159)

* Fri Jun 02 2017 neoclust <neoclust> 230-11.mga6
+ Revision: 1105817
- Add P1000 - Fixes  CVE-2017-9217 (mga#20968)

* Sun May 07 2017 tmb <tmb> 230-10.mga6
+ Revision: 1099541
- tmpfiles: downgrade error message when operation is not supported (mga#20753)

* Thu Feb 09 2017 daviddavid <daviddavid> 230-9.mga6
+ Revision: 1085221
- backport and rebase upstream patch for gperf 3.1 api change

* Mon Jan 16 2017 tv <tv> 230-8.mga6
+ Revision: 1081988
- remove BR on qemu
- disable systemd-timesyncd by default (mga#15019, mga#15534, mga#17091, mga#19113)

* Wed Nov 30 2016 ngompa <ngompa> 230-6.mga6
+ Revision: 1071259
- Remove Conflicts on plymouth-quit.service to fix prefdm starting sddm (mga#19216, mga#19781, mga#19782)

* Sun Oct 02 2016 colin <colin> 230-5.mga6
+ Revision: 1058131
- Add upstream fixes for CVE-2016-7795 mga#19494

* Wed Aug 31 2016 colin <colin> 230-4.mga6
+ Revision: 1049609
- Hopefully fully fix rfkill stop job queue blockage mga#16647

* Thu Jun 23 2016 tmb <tmb> 230-3.mga6
+ Revision: 1037329
- silence udev version print during boot as it breaks splash

* Tue Jun 07 2016 colin <colin> 230-1.mga6
+ Revision: 1020575
- Disable dnssec for now (as recommended upstream)
- Lock down fbdev (upstream)
- Fix automount expiry+remount (upstream)
- * New version: v230
  * Keep previous logind user process handling behaviour (do not kill screen)

* Mon Mar 14 2016 colin <colin> 229-3.mga6
+ Revision: 990480
- Add patch to fix device manager crash mga#17766

* Tue Mar 08 2016 tv <tv> 229-2.mga6
+ Revision: 987309
- '|| :' won't preven ignoring exec faillures...
- ignore filetrigger faillure
- obsoletes prcsys

* Sat Feb 13 2016 colin <colin> 229-1.mga6
+ Revision: 959609
- New version: 229

* Mon Jan 18 2016 colin <colin> 228-1.mga6
+ Revision: 925318
- New version: 228

* Mon Jan 11 2016 luigiwalser <luigiwalser> 227-4.mga6
+ Revision: 921838
- rebuild for gnutls

* Fri Dec 18 2015 pterjan <pterjan> 227-3.mga6
+ Revision: 911567
- Rebuild for new libmicrohttpd

* Tue Nov 03 2015 tv <tv> 227-2.mga6
+ Revision: 897584
- Obsoletes: gummiboot
+ colin <colin>
- New version: 227

* Thu Sep 10 2015 fwang <fwang> 225-3.mga6
+ Revision: 875364
- rebuild for new libgcrypt
+ blino <blino>
- do not buildrequire valgrind on armv5 or mips (not available)
- remove python-sphinx buildrequire now that python-systemd has been split out
- remove dbus-glib-devel buildrequires
- buildrequire qemu on x86 only (only needed to test EFI images)
- drop vala buildrequires

* Sat Sep 05 2015 tv <tv> 225-2.mga6
+ Revision: 873139
- switch to new upstream file trigger syntax
- kill older triggers
  (rpm only fire one of identical pkg trigger)
  (which is now warned by rpm-4.13)

* Wed Sep 02 2015 colin <colin> 225-1.mga6
+ Revision: 872167
- New version: 225

* Fri Aug 21 2015 tmb <tmb> 224-3.mga6
+ Revision: 867050
- rebuild with new gcc

* Thu Aug 20 2015 tmb <tmb> 224-2.mga6
+ Revision: 866906
- rebuild with gcc 5.2.1

* Sat Aug 01 2015 colin <colin> 224-1.mga6
+ Revision: 860379
- New version: 224

* Wed Jul 29 2015 colin <colin> 223-1.mga6
+ Revision: 858935
- New version: 223
- Drop python-systemd (it's in a separate package now)

* Wed Jul 08 2015 colin <colin> 222-1.mga6
+ Revision: 852740
- New version: 222

* Thu Jun 25 2015 colin <colin> 221-2.mga6
+ Revision: 842910
- Fix chkconfig requires

* Thu Jun 25 2015 colin <colin> 221-1.mga6
+ Revision: 842862
- New version: 221
- Drop TIMEOUT= revert (hopefully no longer needed)
- Rediff needed patches
- Drop chkconfig patches (chkconfig updated & sysv support reworked)
- Drop libgudev (split to separate package)
- Build from git tarball (upstream request for future releases)

* Wed Jun 03 2015 tmb <tmb> 217-11.mga5
+ Revision: 822879
- push to /release

* Wed Jun 03 2015 tmb <tmb> 217-10.mga5
+ Revision: 822874
- everywhere: remove configurability of sysv runlevel to target mapping (mga#15670)

* Tue May 12 2015 akien <akien> 217-9.mga5
+ Revision: 821935
- udev: downgrade a few warnings to debug messages (mga#14817)

* Sun Feb 08 2015 colin <colin> 217-8.mga5
+ Revision: 814221
- Don't create system users we don't need (upstream)
- Better deal with destroying cgroups (don't hide processes still running) (upstream)
- Get proper user privs for journal capturing of stdout/err (upstream)
- Fix ioctl for revoke emulation in logind (upstream)
- Support more search paths for locales (mga)

* Mon Nov 10 2014 colin <colin> 217-7.mga5
+ Revision: 796188
- ensure sync() on forced reboots (upstream)
- ensure vconsole-setup is rerun appropriately as needed (upstream)

* Fri Nov 07 2014 colin <colin> 217-6.mga5
+ Revision: 795996
- Add upstream fix for poweroff->reboot issue (mga#14432)
- Change hwdb updates to filetriggers
- Change journal catalog updates to filetriggers

* Tue Nov 04 2014 colin <colin> 217-5.mga5
+ Revision: 795651
- Use Type=notify for journald to prevent flush race (mga#14452)
- Revert hwdb patch as it cannot find our file in /etc/udev/hwdb.bin

* Tue Nov 04 2014 colin <colin> 217-4.mga5
+ Revision: 795591
- Quick hack to see if it helps with mga#14452

* Mon Nov 03 2014 colin <colin> 217-3.mga5
+ Revision: 795327
- Add a couple cherry picks from upstream (mga#14444, mga#14427)

* Sun Nov 02 2014 colin <colin> 217-2.mga5
+ Revision: 795202
- Fix error about binding to systemd notify socket.

* Thu Oct 30 2014 colin <colin> 217-1.mga5
+ Revision: 794712
- Fix an issue with nspawn for bind mount points that already exist
- Remove references to systemd-readahead which is no longer packaged
- New version: 217

* Mon Oct 27 2014 colin <colin> 216-10.mga5
+ Revision: 793905
- Move preset definitions to systemd-units for proper service enabling

* Mon Oct 27 2014 colin <colin> 216-9.mga5
+ Revision: 793898
- Do not enable some less common services (disabled by preset, but policy not yet installed)

* Sun Oct 19 2014 colin <colin> 216-8.mga5
+ Revision: 791617
- Do not run tmpfiles manually on first install (filetriggers should handle)

* Wed Oct 15 2014 umeabot <umeabot> 216-7.mga5
+ Revision: 742458
- Second Mageia 5 Mass Rebuild

* Sat Oct 04 2014 colin <colin> 216-6.mga5
+ Revision: 736848
- Remove dangling symlinks for no longer needed devel libraries

* Fri Oct 03 2014 tmb <tmb> 216-5.mga5
+ Revision: 736578
- rebuild for deps

* Sat Sep 27 2014 tv <tv> 216-4.mga5
+ Revision: 730468
- rebuild for missing pythoneggs deps

* Fri Sep 26 2014 wally <wally> 216-3.mga5
+ Revision: 724961
- rebuild with new rpm-mageia-setup to generate requires for .typelib files

* Tue Sep 16 2014 umeabot <umeabot> 216-2.mga5
+ Revision: 689666
- Mageia 5 Mass Rebuild

* Sun Aug 31 2014 colin <colin> 216-1.mga5
+ Revision: 669819
- Add missing BRs for new version
- Obsolete bootchart
- New version: 216
- New version: 215
- Fix daemon-reload filetrigger (only one line and cover sysvinit too)
- Consolidate library packages to the upstream libsystemd lib
- Add (prioritized) filetriggers for sysusers and tmpfiles
- Drop upstream patches
- Rebase downstream patches
- Provide compat pkgconfig .pc files for deprecated libs
- Add temporary devel() Provides hacks to allow convenient rebuilds
+ pterjan <pterjan>
- Rebuild for new Python

* Wed Apr 16 2014 colin <colin> 208-15.mga5
+ Revision: 615235
- Update to latest v208-stable (incl. ask-password buffer o/f fix mga#13219)
- Rebase downstream patch
- Drop reverting of upstream change (the underlying issue should be resolved)

* Tue Feb 25 2014 colin <colin> 208-14.mga5
+ Revision: 596920
- Switch to official stable branch for 208 patches.

* Sun Feb 23 2014 colin <colin> 208-13.mga5
+ Revision: 595992
- Disable those patches which are also disabled in Fedora.

* Sun Feb 23 2014 colin <colin> 208-12.mga5
+ Revision: 595970
- Sync with Fedora backport fixes for v208

* Sun Feb 09 2014 colin <colin> 208-11.mga5
+ Revision: 587060
- Drop problematic patch from Fedora (subsequently dropped) related to /run/nologin
- Fix path to root-fsck service (mostly cosmetic)

* Mon Jan 27 2014 colin <colin> 208-10.mga4
+ Revision: 568432
- Default to the 'insecure' sysrq options (should be handled by msec long term) mga#10473
- Add a patch to work around user-session exit problems (slowing shutdown)

* Wed Jan 22 2014 colin <colin> 208-9.mga4
+ Revision: 567415
- Fix static nodes when multiple nodes are supplied in a single rule mga#12382

* Thu Jan 16 2014 colin <colin> 208-8.mga4
+ Revision: 566664
- Various upstream backports (brings patchset roughly in line with fedora)

* Mon Jan 13 2014 colin <colin> 208-7.mga4
+ Revision: 566495
- Require chkconfig version with the appropriate patch for smooth upgrades mga#12278

* Mon Jan 13 2014 colin <colin> 208-6.mga4
+ Revision: 566488
- Ensure native unit [Install] section information is suppressed for sysvinit scripts on enable
- Ensure chkconfig does not reload systemd when we are mid-operation (mga#12278)
- Process installed tmpfiles on first install (handles early pkg ordering issues)
- Add upstream/backported fixes for various logind issues.
- Suppress (albeit harmless) PAM error during su/sudo (resulting from SuSE patch)

* Mon Dec 09 2013 colin <colin> 208-5.mga4
+ Revision: 556011
- Drop redundant patch (/var/run IS a symlink to /run) and renumber
- Add upstream cherry pick to not set XDG_RUNTIME_DIR when raising privs.
- Add upstream cherry-picks (same set as Fedora)
- Use correct tarball

* Thu Oct 31 2013 colin <colin> 208-4.mga4
+ Revision: 548137
- Revert conversion to posttrans as this doesn't run the needed scripts on first install

* Tue Oct 29 2013 tv <tv> 208-3.mga4
+ Revision: 547777
- move systemd-unit %%post into %%posttrans (trying to fix install deps loop errors)

* Mon Oct 21 2013 umeabot <umeabot> 208-2.mga4
+ Revision: 540515
- Mageia 4 Mass Rebuild

* Tue Oct 08 2013 colin <colin> 208-1.mga4
+ Revision: 493791
- Ensure the systemd-journal group is created before installing (mga#11264)
- New version: 208
- Rename the network rules to come after network device renaming

* Sun Sep 22 2013 colin <colin> 207-2.mga4
+ Revision: 483351
- Ensure the 'systemd-journal' group is created at install time (mga#11264)

* Sat Sep 21 2013 colin <colin> 207-1.mga4
+ Revision: 482887
- New version: 207
- Add various patches from upstream
- Revert problematic patch from upstream leading to startup delays
- Add patch from ML to address a timeout problem when stopping type=notify units

* Wed Sep 11 2013 colin <colin> 206-8.mga4
+ Revision: 477592
- Rebuild for new libcryptsetup

* Mon Sep 09 2013 colin <colin> 206-7.mga4
+ Revision: 476579
- Enable chkconfig support (mga#11191)

* Mon Sep 02 2013 colin <colin> 206-6.mga4
+ Revision: 474322
- Fix logind race condition (causes unlock issue in GNOME fdo#67273)

* Wed Aug 07 2013 colin <colin> 206-5.mga4
+ Revision: 464364
- Fix getty@ template service enabling at install time (mga#10931)

* Wed Aug 07 2013 colin <colin> 206-4.mga4
+ Revision: 464295
- Drop old, unrecognised configure arguments.
- Pass the Mageia path to rc.local script for compatibility (mga#10942)

* Fri Jul 26 2013 colin <colin> 206-3.mga4
+ Revision: 458501
- Add some upstream cherry-picks.
- Add upstream fix for udev static node permissions (mga#10840)

* Thu Jul 25 2013 colin <colin> 206-2.mga4
+ Revision: 457926
- Reorder scripts (spec cosmetics)
- Convert the netif name change disabling to a triggerun (mga4 feature)
- Perform a few extra housekeeping jobs after install/upgrade
- Ensure hwdb is properly shipped and populated on install/upgrade

* Thu Jul 25 2013 colin <colin> 206-1.mga4
+ Revision: 457904
- Enable consistent network device naming but disable on upgrade (mga4 feature)
- Remove the racy network device renaming loop patch + netif rules generator (mga4 feature)
- Provide the nss-myhostname package (with higher version than current separate package)
- nsswitch.conf patching not included in favour of including directly in default conf in glibc
- New version: 206
- Drop upstream cherry-pick patches
- Fix file lists
- Rediff Mageia patches

* Tue Jun 18 2013 colin <colin> 204-2.mga4
+ Revision: 444838
- Apply various upstream fixes

* Sat May 25 2013 colin <colin> 204-1.mga4
+ Revision: 427633
- New version: 204
- Drop upstream cherry pick patches
- Move systemd-analyze to main package and deprecated systemd-tools package

* Fri May 03 2013 colin <colin> 195-22.mga3
+ Revision: 412191
- Make default journal default to leaving 15%% free space (mga#9921)

* Sun Apr 28 2013 colin <colin> 195-21.mga3
+ Revision: 411531
- Kill unneeded directory
- Fix floating point errors with two upstream cherry picks (mga#9850)
- Re-enable previously disabled patches now that floating point error is fixed (mga#9689)

* Thu Apr 11 2013 colin <colin> 195-20.mga3
+ Revision: 409599
- Add some missing patches from SuSE package analysis
- Disable udev patches to prevent Floating point exception (mga#9689)

* Mon Apr 08 2013 colin <colin> 195-19.mga3
+ Revision: 409144
- Compile, but do not enable the coredump capturing capabilities
- Add numerous upstream patches (after reviewing SuSE package patches)
- Add SuSE patch to restore cdrw, dvd and dvdrw symlinks (mga#8524)

* Mon Apr 01 2013 colin <colin> 195-18.mga3
+ Revision: 406960
- Fix the (ugly) net rule generator to not call udevadm info --run which no longer exists

* Mon Apr 01 2013 colin <colin> 195-17.mga3
+ Revision: 406949
- Fix install line
- Make the write_net_rules able to make the rules dir if needed
- Ship /etc/udev/rules.d folder for user rules.

* Fri Feb 08 2013 colin <colin> 195-16.mga3
+ Revision: 395370
- Provide 'system-logger' rather than 'syslog-daemon' as some pkgs may require a real syslog

* Tue Feb 05 2013 tmb <tmb> 195-15.mga3
+ Revision: 394711
- write_net_rules needs to be executable to actually work

* Sun Jan 27 2013 colin <colin> 195-14.mga3
+ Revision: 392732
- Add some more upstream patches to solve problems of overzealous cleanup of PrivateTmp=yes dirs

* Sun Jan 27 2013 colin <colin> 195-13.mga3
+ Revision: 392724
- The quota services are now pulled in by mount points, hence no need to enable them explicitly

* Sun Jan 27 2013 colin <colin> 195-12.mga3
+ Revision: 392699
- Fully obsolete main sysvinit package (tools are still required)

* Sat Jan 26 2013 colin <colin> 195-11.mga3
+ Revision: 392489
- Drop a patch that has not been needed since the fstab generator rewrite

* Sat Jan 26 2013 colin <colin> 195-10.mga3
+ Revision: 392484
- Add various upstream fixes (those included in fedora's v195 package)
- Add back the sub-optimal network interface generator until mga4 i/f rename

* Tue Jan 22 2013 tv <tv> 195-9.mga3
+ Revision: 391054
- adjust group

* Tue Jan 15 2013 colin <colin> 195-8.mga3
+ Revision: 388269
- Fix build with latest glibc
- Fix autoreconf call (missing build-aux/test-driver)
- Remove ghosted files in /etc. Not needed.
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 13 2012 colin <colin> 195-6.mga3
+ Revision: 330108
- Relax perms on /sys/kernel/debug for lspcidrake by non-root

* Thu Nov 29 2012 colin <colin> 195-5.mga3
+ Revision: 322974
- Apply upstream patch to fix a crash related service name lookups.
- Enable xz compression in journal logs.

* Wed Nov 07 2012 blino <blino> 195-4.mga3
+ Revision: 315425
- restart systemd-logind.service on systemd 195 upgrade to fix errors on login (logind protocol changed)

* Tue Nov 06 2012 blino <blino> 195-3.mga3
+ Revision: 314560
- obsolete consolekit, replaced by systemd-logind

* Sun Oct 28 2012 colin <colin> 195-2.mga3
+ Revision: 311312
- Enable persistent journal logs and provide syslog-daemon

* Tue Oct 23 2012 colin <colin> 195-1.mga3
+ Revision: 309449
- New version: 195
- Drop patches committed upstream

* Tue Oct 23 2012 cjw <cjw> 194-3.mga3
+ Revision: 309338
- add back udev support for interface renaming that was removed upstream

* Tue Oct 16 2012 colin <colin> 194-2.mga3
+ Revision: 307118
- Hopefully fix journald mmap leaks (mga#7675)

* Mon Oct 08 2012 colin <colin> 194-1.mga3
+ Revision: 303584
- New version: 194
- Drop tmpfiles filetrigger - it runs too late to be of universal usefulness

* Tue Oct 02 2012 guillomovitch <guillomovitch> 193-2.mga3
+ Revision: 302245
- add rpm filetriggers to run systemd-tmpfiles immediatly after package
  installation (fix #7569)

* Sun Sep 30 2012 colin <colin> 193-1.mga3
+ Revision: 301032
- Add BuildRequires on libmicrohttpd for journal-gatewayd
- New version: 193

* Thu Sep 27 2012 colin <colin> 192-1.mga3
+ Revision: 298538
- New version: 192
- Drop upstream applied patches

* Thu Sep 13 2012 colin <colin> 189-5.mga3
+ Revision: 293658
- Add epoch to usermode conflict

* Fri Sep 07 2012 colin <colin> 189-4.mga3
+ Revision: 289306
- Move reboot, halt and poweroff to bindir (removed from usermode)

* Tue Sep 04 2012 colin <colin> 189-3.mga3
+ Revision: 288278
- Various fixes to logind (sent upstream)

* Tue Aug 28 2012 colin <colin> 189-2.mga3
+ Revision: 284851
- Drop /proc/bus/usb mount as it's no longer available with kernels >= 3.5

* Fri Aug 24 2012 colin <colin> 189-1.mga3
+ Revision: 283679
- New version: 189

* Sat Aug 11 2012 colin <colin> 188-1.mga3
+ Revision: 280625
- New version: 188
- Rediff patches (restore prefdm removed from upstream for now)

* Sun Jul 29 2012 wally <wally> 187-6.mga3
+ Revision: 275776
- fix GUdev gir typelib pkg conflicts

* Sun Jul 29 2012 wally <wally> 187-5.mga3
+ Revision: 275772
- fix systemd-id128 library package name
- create a subpkg for GUdev gir typelib

* Tue Jul 24 2012 colin <colin> 187-4.mga3
+ Revision: 273984
- Rebuild with new cryptsetup

* Sun Jul 22 2012 blino <blino> 187-3.mga3
+ Revision: 273550
- remove /run/.mageia-network check for network initscript, unneded now that /var/lock is a symlink to /run/lock

* Sun Jul 22 2012 colin <colin> 187-2.mga3
+ Revision: 273411
- Update for a post-usrmove world

* Fri Jul 20 2012 colin <colin> 187-1.mga3
+ Revision: 272814
- New version: 187

* Thu Jul 19 2012 blino <blino> 186-2.mga3
+ Revision: 272623
- create and own /usr/lib/systemd/ntp-units.d (like in Fedora, useful for systemd >= 186)

* Wed Jul 04 2012 colin <colin> 186-1.mga3
+ Revision: 267780
- Simplify -devel packaging (one systemd, one udev, one gudev)
- New version: 186
- Drop upstream cherry-pick patches
- Drop upstream applied patches
- Rebase remaining patches (update udevadm settle patch for new code style)
- Drop redundant config file tweaks

* Sun Jul 01 2012 colin <colin> 185-4.mga3
+ Revision: 266233
- Migrate missing rules and related helpers from udev package.
- Migrate all missed patches from udev package (except udev-acl)

* Sun Jul 01 2012 colin <colin> 185-3.mga3
+ Revision: 265987
- Fix a missed service rename reference.

* Sat Jun 30 2012 colin <colin> 185-2.mga3
+ Revision: 265522
- Rename systemd-udev.service to systemd-udevd.service (upstream approved)

* Fri Jun 29 2012 colin <colin> 185-1.mga3
+ Revision: 264925
- New version: 185
- Merge udev package into systemd (upstream merge)
- Merge systemd-sysvinit into systemd package (sysvinit is no longer supported)
- Drop patches applied upstream.
- Cherry pick selected upstream commits
- Rebase Mageia customisation patches.
- Reimplement noauto patch for fstab entries (to prevent network mounts holding up login)
- Fix -devel library names (drop major)

* Thu Jun 14 2012 guillomovitch <guillomovitch> 185-0.1.mga3
+ Revision: 260575
- drop patch 511 (nfs-common service dependency)

* Sun May 20 2012 colin <colin> 44-13.mga2
+ Revision: 235955
- Ensure that common NFS services are started before any shares are mounted (mga#5890)

* Thu May 10 2012 colin <colin> 44-12.mga2
+ Revision: 235024
- Fix a memory leak in logind
- Include upstream commit to ignore getty's on isloation (mga#5760)
- Fix issue with rescue shell on fsck errors (rhbz#798328)
- Fix issue on overzealous process killing (rhbz#816842, rhbz#805942)
- Use generic target for ntp related implementations (allows migration to chrony in the future)
- Add upstream fix for leftover /tmp/systemd-namespace* folders (mga#5602, rhbz#810257)
- Renumber patches to drop fully patch 121 (which is already excluded)

* Wed May 02 2012 colin <colin> 44-11.mga2
+ Revision: 234557
- Silence systemd output when starting getty (mga#5091)
- Fix SIGRTMIN+21 value (I previously miscalculated)

* Sun Apr 29 2012 colin <colin> 44-10.mga2
+ Revision: 234189
- Default to multi-user.target on initial install as per initscripts (mga#5668)

* Thu Apr 26 2012 colin <colin> 44-9.mga2
+ Revision: 233322
- Fix an issue where Mageia specific code in m4 files was not processed.

* Tue Apr 17 2012 colin <colin> 44-8.mga2
+ Revision: 231247
- Drop patch that creates an ordering cycle on syslog rather than preventing it
- Mark some config files as such.
+ alien <alien>
- Ask the user to reboot if this package is updated (mga#5388)

* Sun Apr 08 2012 colin <colin> 44-7.mga2
+ Revision: 229702
- Drop upstream patch as it seems to break OnFailure handiling.
- Tweak the display-manager-failure message to show up quicker (and use agetty)

* Sun Apr 08 2012 colin <colin> 44-6.mga2
+ Revision: 229679
- Bump for sysvinit-legacy

* Fri Apr 06 2012 colin <colin> 44-5.mga2
+ Revision: 229315
- More upstream cherry-picks
- Small fix to display manager failure system.

* Sun Apr 01 2012 colin <colin> 44-4.mga2
+ Revision: 227734
- Rebuild for new sysvinit-legacy
- No need to remove var-{lock,run}.mount units. Upstream patch removes them.
- No need to set MountAuto/SwapAuto to yes. This is the default.

* Sun Apr 01 2012 colin <colin> 44-3.mga2
+ Revision: 227667
- Numerous upstream cherry picks
- Drop usless Mandriva patch (we didn't use what it added)
- Ensure network filesystems will hold up DM only when 'nofail' is omitted in fstab
- Do not make DM wait for rc.local (we don't do thus under sysvinit)
- Make the DM failure script start later if it runs
- Fix small cosmetic issue in systemd-analyse when run too quickly after boot
- Note: journalctl and loginctl have now dropped their systemd- prefix

* Thu Mar 22 2012 dmorgan <dmorgan> 44-2.mga2
+ Revision: 225731
- Do not build the gtk UI anymore ( will be in an other rpm)

* Wed Mar 21 2012 colin <colin> 44-1.mga2
+ Revision: 225172
- Don't own /etc/profile.d dir
- New version: 44 (numerous fixes to journal+endien conversions)
- Set default pager to be more color and screen friendly
- Disable journal coredump swallowing until it gets better tools to work with it.
- Do not process modprobe.preload. This is handled by fedora-loadmodules.service
- Add patch to address CVE-2012-1174 (symlink attack)

* Mon Mar 12 2012 colin <colin> 43-5.mga2
+ Revision: 222893
- Disable rsyslog specific hacks - it does it itself now.

* Thu Mar 08 2012 colin <colin> 43-4.mga2
+ Revision: 221745
- Upstream patch to fix journal segvs (mga#4588)
- Add unit to run a special info script on display manager failure (mga#4769)

* Wed Mar 07 2012 tmb <tmb> 43-3.mga2
+ Revision: 221224
- bump sysvinit version-release provides

* Sat Mar 03 2012 colin <colin> 43-2.mga2
+ Revision: 217274
- Interpret splash=silent as an equiv of quiet (prevents some plymouth flickering)
- Recognise 'failsafe' kernel command line as synonym for 'single' (mga#4702)

* Fri Feb 24 2012 colin <colin> 43-1.mga2
+ Revision: 213880
- Add BR for docbook-style-xsl (for man pages)
- Add BR for xsltproc (for man pages)
- Add BR for libkmod
- New version: 43
- Rediffed patches
- Make prefdm conflict with getty@tty1
- Disable statically configured getty's for tty[2-6] (they are auto-activated)
- Fix distro tag in configure and drop now redundant options.

* Thu Feb 16 2012 colin <colin> 40-3.mga2
+ Revision: 209739
- Bump sysvinit release

* Tue Feb 07 2012 dmorgan <dmorgan> 40-2.mga2
+ Revision: 206042
- New version 40
  Enable libcryptsetup support

* Thu Jan 26 2012 dmorgan <dmorgan> 39-3.mga2
+ Revision: 202019
- Rebuild now that lockdev is fixed

* Thu Jan 26 2012 dmorgan <dmorgan> 39-2.mga2
+ Revision: 201786
- Requires lockdev ( mga #3551)

* Wed Jan 25 2012 colin <colin> 39-1.mga2
+ Revision: 201521
- New version: 39
- Enhanced filetriggers and made them non-config files (no more .rpmnews)
- Fixed build error relating to a systemd/user dir
+ dmorgan <dmorgan>
- Fix unown folders

* Fri Jan 20 2012 colin <colin> 38-8.mga2
+ Revision: 198517
- Apply various upstream patches
- Add a work around for a syslog.socket deadlock on boot+shutdown

* Thu Jan 19 2012 dmorgan <dmorgan> 38-7.mga2
+ Revision: 198249
- Add a filetrigger to reload systemd when a service is updated

* Wed Jan 18 2012 dmorgan <dmorgan> 38-6.mga2
+ Revision: 197873
- Add syslog.service in %%post ( from fedora)
- Add syslog fragment

* Mon Jan 16 2012 tmb <tmb> 38-4.mga2
+ Revision: 196777
- adjust sysvinit provides so it has higher rel than current sysvinit

* Sun Jan 15 2012 blino <blino> 38-3.mga2
+ Revision: 196288
- require coreutils, grep and awk for systemd-units post scriptlet

* Fri Jan 13 2012 wally <wally> 38-2.mga2
+ Revision: 195720
- fix libgee BR

* Fri Jan 13 2012 dmorgan <dmorgan> 38-1.mga2
+ Revision: 195688
- New version 38

* Wed Dec 28 2011 dmorgan <dmorgan> 37-18.mga2
+ Revision: 188452
- Do not use systemd-sysv-convert anymore

* Mon Dec 19 2011 tv <tv> 37-17.mga2
+ Revision: 184320
- rebuild for partial build
- move systemd-sysv-convert into systemd-tools in order to unbloat minimal install
  (it requires python)

* Thu Dec 15 2011 colin <colin> 37-15.mga2
+ Revision: 182053
- Do not start getty on tty1, it's used for X11 now (mga#3430)

* Sun Dec 11 2011 lmenut <lmenut> 37-14.mga2
+ Revision: 180654
- add BuildRequires: gettext-devel, as intltool does not require it anymore
- systemd-analyze requires python-dbus & python-cairo

* Mon Nov 28 2011 colin <colin> 37-13.mga2
+ Revision: 173732
- * Fix hostname script (can't use spaces after =)
  * Tidy up variable names and mask any errors in reading files in hostname script

* Mon Nov 28 2011 dmorgan <dmorgan> 37-12.mga2
+ Revision: 173684
- Do not set hostname at first install only but always check if one is set even on upgrade

* Thu Nov 10 2011 dmorgan <dmorgan> 37-11.mga2
+ Revision: 166164
- Fix logic in %%post units

* Wed Nov 09 2011 dmorgan <dmorgan> 37-10.mga2
+ Revision: 165935
- migrate hostname from old init process
- Do not disable hwclock-load.service it does not exist anymore
- Do not enable hwclock-load.service it does not exist anymore

* Fri Nov 04 2011 colin <colin> 37-9.mga2
+ Revision: 162696
- Change how prefdm.service works (more similar to Fedora)

* Mon Oct 31 2011 colin <colin> 37-8.mga2
+ Revision: 160471
- Conflict with sysvinit properly via careful capitalisation.

* Sun Oct 30 2011 blino <blino> 37-7.mga2
+ Revision: 159891
- fix broken conflicts and provides, use version-rel, not rel-rel...
  this should make sysvinit installable again

* Sat Oct 29 2011 dmorgan <dmorgan> 37-6.mga2
+ Revision: 159654
- Rebuild to push in core media
- Fix TARGET_MAGEIA instead of TARGET_MANDRIVA

* Sat Oct 29 2011 colin <colin> 37-5.mga2
+ Revision: 159642
- Update Mageia support patch
- * Remove the parsing of /etc/mageia-release and depend on os-release
- * Link dm.service to prefdm.service to mask sysvinit version
- * Remove dependance on syslog.service as this is handled internally
- Do not own /etc/os-release (this should be in a different package)
- Remove some unneeded patches
- Add some annotations to patches to indicate where they are going (upstream/drop etc) in the future.

* Tue Oct 25 2011 dmorgan <dmorgan> 37-4.mga2
+ Revision: 158036
- Add polkit as requires in the gtk subpackage
- Include systemd-sysv-convert (Fedora )
- Own more files ( from fedora)
- Own more files
  Use rpm macro for /etc

* Sat Oct 22 2011 colin <colin> 37-3.mga2
+ Revision: 157408
- Cherry-pick some upstream patches.
- Add various patches from Mandriva.
- Do not remove units and take over several tasks from initscripts

* Mon Oct 17 2011 colin <colin> 37-2.mga2
+ Revision: 155702
- Fixup directory ownership and include some (deliberately) empty directories
+ guillomovitch <guillomovitch>
- redundant with autoreconf usage
- implicit build dependencies

* Wed Oct 12 2011 dmorgan <dmorgan> 37-1.mga2
+ Revision: 154059
- New version 37

* Sun Oct 09 2011 dmorgan <dmorgan> 36-1.mga2
+ Revision: 153503
- New version 36

* Wed Sep 28 2011 ovitters <ovitters> 35-5.mga2
+ Revision: 149939
- fix conflicts of devel,tool subpackages
+ dmorgan <dmorgan>
- Requires nss-myhostname

* Mon Sep 19 2011 tv <tv> 35-4.mga2
+ Revision: 145664
- bump release
- split out systemd-analyze in systemd-tools since it requires python
  (saves 30mb in minimal basesystem)
  also do not pulls pkgconfig in minimal basesystem

* Fri Sep 09 2011 dmorgan <dmorgan> 35-3.mga2
+ Revision: 141908
- Comment non working command (need debugging)
- Remove rpm macro, will be in rpm-setup

* Fri Sep 09 2011 dmorgan <dmorgan> 35-2.mga2
+ Revision: 141666
- add macros.systemd file for %%{_unitdir}

* Thu Sep 08 2011 dmorgan <dmorgan> 35-1.mga2
+ Revision: 141393
- New version 35
- Add some configuration file
  Add %%post with default commands ( ex: systemd-machine-id-setup )
- Add upstream patches to fix build ( tpg )
  Add gperf as Buildrequire
- Remove old source
- Fix mageia detection
- Specify the distro
- Rediff patch13
- New version 32
  Rediff Mageia support patch
  fix file lists ( based on eugeni work )
+ colin <colin>
- New version: 34

* Fri Jul 15 2011 colin <colin> 30-2.mga2
+ Revision: 124435
- Fixup systemd Mageia support patch
  o Use tabs rather than spaces in Makefile (otherwise it chokes)
  o Fix a TARGET_MANDRIVA -> TARGET_MAGEIA leftover.
  o Fix a define handling leftover in service.c
+ dmorgan <dmorgan>
- Add mageia support in systemd

* Fri Jul 15 2011 dmorgan <dmorgan> 30-1.mga2
+ Revision: 124355
- Fix udev buildrequire version
- Rebuild against new libnotify
+ eugeni <eugeni>
- We need /run to use systemd properly.
- Updated to systemd 30
+ mikala <mikala>
- Add patch14 so systemd can build with vala 0.12

* Thu Feb 17 2011 dmorgan <dmorgan> 18-1.mga1
+ Revision: 52867
- Fix file list
- New version
  Remove patch15: Merged upstream

* Sat Feb 12 2011 spuhler <spuhler> 17-2.mga1
+ Revision: 51174
- initial import
- removed Patch14:	systemd-17-hwclock-hctosys.patch
  added Patch15:	systemd-17-fix-cgroup.patch
- added patch 14
- added Requires: systemd-units = %%{EVRD}
  added +Patch14:   systemd-17-hwclock-hctosys.patch
- removed buildroot definition from .spec
  put buildrequires each in one line
+ dmorgan <dmorgan>
- Use fedora as distro name as mageia is not yet defined
- Fix distro name
- Merge mdv commit 634092
- New version 17
- Remove old binaries
- Sync with mdv

* Mon Jan 17 2011 blino <blino> 15-5.mga1
+ Revision: 21515
- adapt requires
- rename /etc/release patch
- use /etc/release file
- imported package systemd

